Class: VeloPayments::CreatePayeeAddress
- Inherits:
-
Object
- Object
- VeloPayments::CreatePayeeAddress
- Defined in:
- lib/velopayments/models/create_payee_address.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
Ideally a 2 letter ISO 3166-1 country code.
-
#county_or_province ⇒ Object
Returns the value of attribute county_or_province.
-
#line1 ⇒ Object
Returns the value of attribute line1.
-
#line2 ⇒ Object
Returns the value of attribute line2.
-
#line3 ⇒ Object
Returns the value of attribute line3.
-
#line4 ⇒ Object
Returns the value of attribute line4.
-
#zip_or_postcode ⇒ Object
Returns the value of attribute zip_or_postcode.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePayeeAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePayeeAddress
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/velopayments/models/create_payee_address.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `VeloPayments::CreatePayeeAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `VeloPayments::CreatePayeeAddress`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'line1') self.line1 = attributes[:'line1'] end if attributes.key?(:'line2') self.line2 = attributes[:'line2'] end if attributes.key?(:'line3') self.line3 = attributes[:'line3'] end if attributes.key?(:'line4') self.line4 = attributes[:'line4'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'county_or_province') self.county_or_province = attributes[:'county_or_province'] end if attributes.key?(:'zip_or_postcode') self.zip_or_postcode = attributes[:'zip_or_postcode'] end if attributes.key?(:'country') self.country = attributes[:'country'] end end |
Instance Attribute Details
#city ⇒ Object
Returns the value of attribute city.
25 26 27 |
# File 'lib/velopayments/models/create_payee_address.rb', line 25 def city @city end |
#country ⇒ Object
Ideally a 2 letter ISO 3166-1 country code. But a limited set of additional values will be corrected. See Java Locale.getISOCountries() and Locale.getDisplayCountry()
32 33 34 |
# File 'lib/velopayments/models/create_payee_address.rb', line 32 def country @country end |
#county_or_province ⇒ Object
Returns the value of attribute county_or_province.
27 28 29 |
# File 'lib/velopayments/models/create_payee_address.rb', line 27 def county_or_province @county_or_province end |
#line1 ⇒ Object
Returns the value of attribute line1.
17 18 19 |
# File 'lib/velopayments/models/create_payee_address.rb', line 17 def line1 @line1 end |
#line2 ⇒ Object
Returns the value of attribute line2.
19 20 21 |
# File 'lib/velopayments/models/create_payee_address.rb', line 19 def line2 @line2 end |
#line3 ⇒ Object
Returns the value of attribute line3.
21 22 23 |
# File 'lib/velopayments/models/create_payee_address.rb', line 21 def line3 @line3 end |
#line4 ⇒ Object
Returns the value of attribute line4.
23 24 25 |
# File 'lib/velopayments/models/create_payee_address.rb', line 23 def line4 @line4 end |
#zip_or_postcode ⇒ Object
Returns the value of attribute zip_or_postcode.
29 30 31 |
# File 'lib/velopayments/models/create_payee_address.rb', line 29 def zip_or_postcode @zip_or_postcode end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/velopayments/models/create_payee_address.rb', line 35 def self.attribute_map { :'line1' => :'line1', :'line2' => :'line2', :'line3' => :'line3', :'line4' => :'line4', :'city' => :'city', :'county_or_province' => :'countyOrProvince', :'zip_or_postcode' => :'zipOrPostcode', :'country' => :'country' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
372 373 374 |
# File 'lib/velopayments/models/create_payee_address.rb', line 372 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/velopayments/models/create_payee_address.rb', line 49 def self.openapi_types { :'line1' => :'String', :'line2' => :'String', :'line3' => :'String', :'line4' => :'String', :'city' => :'String', :'county_or_province' => :'String', :'zip_or_postcode' => :'String', :'country' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/velopayments/models/create_payee_address.rb', line 344 def ==(o) return true if self.equal?(o) self.class == o.class && line1 == o.line1 && line2 == o.line2 && line3 == o.line3 && line4 == o.line4 && city == o.city && county_or_province == o.county_or_province && zip_or_postcode == o.zip_or_postcode && country == o.country end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/velopayments/models/create_payee_address.rb', line 400 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model VeloPayments.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/velopayments/models/create_payee_address.rb', line 465 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/velopayments/models/create_payee_address.rb', line 379 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
359 360 361 |
# File 'lib/velopayments/models/create_payee_address.rb', line 359 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
365 366 367 |
# File 'lib/velopayments/models/create_payee_address.rb', line 365 def hash [line1, line2, line3, line4, city, county_or_province, zip_or_postcode, country].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/velopayments/models/create_payee_address.rb', line 112 def list_invalid_properties invalid_properties = Array.new if @line1.nil? invalid_properties.push('invalid value for "line1", line1 cannot be nil.') end if @line1.to_s.length > 100 invalid_properties.push('invalid value for "line1", the character length must be smaller than or equal to 100.') end if @line1.to_s.length < 1 invalid_properties.push('invalid value for "line1", the character length must be great than or equal to 1.') end if !@line2.nil? && @line2.to_s.length > 100 invalid_properties.push('invalid value for "line2", the character length must be smaller than or equal to 100.') end if !@line2.nil? && @line2.to_s.length < 0 invalid_properties.push('invalid value for "line2", the character length must be great than or equal to 0.') end if !@line3.nil? && @line3.to_s.length > 100 invalid_properties.push('invalid value for "line3", the character length must be smaller than or equal to 100.') end if !@line3.nil? && @line3.to_s.length < 0 invalid_properties.push('invalid value for "line3", the character length must be great than or equal to 0.') end if !@line4.nil? && @line4.to_s.length > 100 invalid_properties.push('invalid value for "line4", the character length must be smaller than or equal to 100.') end if !@line4.nil? && @line4.to_s.length < 0 invalid_properties.push('invalid value for "line4", the character length must be great than or equal to 0.') end if @city.nil? invalid_properties.push('invalid value for "city", city cannot be nil.') end if @city.to_s.length > 50 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 50.') end if @city.to_s.length < 2 invalid_properties.push('invalid value for "city", the character length must be great than or equal to 2.') end if !@county_or_province.nil? && @county_or_province.to_s.length > 50 invalid_properties.push('invalid value for "county_or_province", the character length must be smaller than or equal to 50.') end if !@county_or_province.nil? && @county_or_province.to_s.length < 2 invalid_properties.push('invalid value for "county_or_province", the character length must be great than or equal to 2.') end if !@zip_or_postcode.nil? && @zip_or_postcode.to_s.length > 60 invalid_properties.push('invalid value for "zip_or_postcode", the character length must be smaller than or equal to 60.') end if !@zip_or_postcode.nil? && @zip_or_postcode.to_s.length < 2 invalid_properties.push('invalid value for "zip_or_postcode", the character length must be great than or equal to 2.') end if @country.nil? invalid_properties.push('invalid value for "country", country cannot be nil.') end if @country.to_s.length > 50 invalid_properties.push('invalid value for "country", the character length must be smaller than or equal to 50.') end if @country.to_s.length < 2 invalid_properties.push('invalid value for "country", the character length must be great than or equal to 2.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
445 446 447 |
# File 'lib/velopayments/models/create_payee_address.rb', line 445 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
451 452 453 454 455 456 457 458 459 |
# File 'lib/velopayments/models/create_payee_address.rb', line 451 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
439 440 441 |
# File 'lib/velopayments/models/create_payee_address.rb', line 439 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/velopayments/models/create_payee_address.rb', line 195 def valid? return false if @line1.nil? return false if @line1.to_s.length > 100 return false if @line1.to_s.length < 1 return false if !@line2.nil? && @line2.to_s.length > 100 return false if !@line2.nil? && @line2.to_s.length < 0 return false if !@line3.nil? && @line3.to_s.length > 100 return false if !@line3.nil? && @line3.to_s.length < 0 return false if !@line4.nil? && @line4.to_s.length > 100 return false if !@line4.nil? && @line4.to_s.length < 0 return false if @city.nil? return false if @city.to_s.length > 50 return false if @city.to_s.length < 2 return false if !@county_or_province.nil? && @county_or_province.to_s.length > 50 return false if !@county_or_province.nil? && @county_or_province.to_s.length < 2 return false if !@zip_or_postcode.nil? && @zip_or_postcode.to_s.length > 60 return false if !@zip_or_postcode.nil? && @zip_or_postcode.to_s.length < 2 return false if @country.nil? return false if @country.to_s.length > 50 return false if @country.to_s.length < 2 true end |